This directory is generated by [GhostOS](https://github.com/ghost-in-moss/GhostOS) to provide basic usage of GhostOS.

+ configs/: the default config files of GhostOS. 
+ memories/: the local cache files for memory libraries.
+ runtime/: the cache files for runtime object
  + processes/: the processes of the ghost(agent) instance
  + tasks/: the tasks of the ghost
  + threads/: the message thread belongs to tasks
+ scripts/: system scripts that helpful
+ src/: baseline libs or examples 

